# Next


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from core.v1.models.next import Next

# TODO update the JSON string below
json = "{}"
# create an instance of Next from a JSON string
next_instance = Next.from_json(json)
# print the JSON string representation of the object
print(Next.to_json())

# convert the object into a dict
next_dict = next_instance.to_dict()
# create an instance of Next from a dict
next_from_dict = Next.from_dict(next_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


